Changelog
=========

Version 1.0.0 (2017-06-08)
--------------------------

* Initial release

Version 0.2 (2017-10-14)
------------------------

* For NIST TE Challenge 2

Version 0.1.4 (2018-09-30)
--------------------------

* For GridAPPS-D Demo
* GridLAB-D feature/1146 branch with FNCS-controlled switching

Version 0.1.9 (2018-12-13)
--------------------------

* Three desktop version installers for Mac, Windows and Linux
* Tutorial video
* DSO+T study files

Version 0.9.2 (2020-09-11)
--------------------------

* Support for HELICS and EnergyPlus 9.3
* Bundled with ns-3 (HELICS) and opendsscmd (FNCS)
* Execution on Linux or Docker
* Postprocessing on Linux, Windows or Mac OS X

Version 0.9.5 (2021-03-09)
--------------------------

* Standalone housing generator
* Plot functions can save files
* Case-generated SGIP1 example
* Fixed the FNCS SGIP1 example

Version 1.0.1 (2021-04-23)
--------------------------

* Updates to consensus mechanism
* Balanced three-phase houses for housing generator
* Remove deprecated solar and battery attributes
* Update to HELICS 2.6.1






